/*
 * Collision.h
 *
 *  Created on: Jan 10, 2014
 *      Author: brian
 */

#ifndef COLLISION_H_
#define COLLISION_H_


#include "SDL.h"
#include "Vector2D.h"
#include <iostream>

using namespace std;

const static int s_buffer = 8;

static bool RectRect(SDL_Rect* A, SDL_Rect* B, int &xsplash)
{
    int aHBuf = A->h / s_buffer;
    int aWBuf = A->w / s_buffer;

    int bHBuf = B->h / s_buffer;
    int bWBuf = B->w / s_buffer;

    // if the bottom of A is less than the top of B - no collision
    if((A->y + A->h) - aHBuf <= B->y + bHBuf)
    	return false;

    // if the top of A is more than the bottom of B = no collision
    if(A->y + aHBuf >= (B->y + B->h) - bHBuf)
    	return false;

    // if the right of A is less than the left of B - no collision
    if((A->x + A->w) - aWBuf <= B->x +  bWBuf)
    	return false;

    // if the left of A is more than the right of B - no collision
    if(A->x + aWBuf >= (B->x + B->w) - bWBuf)
    	return false;

    int x1 = A->x;
    int x2 = A->x + A->w;
    int x3 = B->x;
    int x4 = B->x + B->w;

    if (x1 > x3 && x2 < x4) {
    	xsplash = (x1 + x2)/2;
    	//cout << "Middle catch at " << (x1 + x2)/2 << endl;
    }

    if (x1 < x3) {
    	xsplash = (x3 + x2)/2;
    	//cout << "left catch at "<< (x3 + x2)/2 << endl;
    }

    if (x2 > x4) {
    	xsplash = (x1 + x4)/2;
      	//cout << "right catch at "<< (x1 + x4)/2 << endl;
    }

    // otherwise there has been a collision
    return true;
}

static bool vector2DRect(Vector2D* A, SDL_Rect* B) {

	if (A->getX() < B->x)
		return false;
	if (A->getX() > (B->x + B->w))
		return false;
	if (A->getY() < B->y)
		return false;

	if (A->getY() > (B->y + B->h))
		return false;
	return true;
}


#endif /* COLLISION_H_ */
